@@ -1,6 +1,5 @@
 # FewShotClassifier must be imported before its child classes
-from .few_shot_classifier import FewShotClassifier
-
+from .few_shot_classifier import FewShotClassifier  # isort:skip
 from .bd_cspn import BDCSPN
 from .finetune import Finetune
 from .matching_networks import MatchingNetworks
